<?php

namespace App\Http\Controllers;


use App\Http\Requests\EmployeeChangePasswordRequest;
use App\Http\Requests\EmployeeRequest;
use App\Http\Requests\EmployeeUpdateForAdminRequest;
use App\Http\Requests\EmployeeUpdateRequest;
use App\Profile;
use App\User;
use Illuminate\Support\Facades\Hash;

class EmployeeController extends Controller
{
    public function index()
    {
        $data = [
            'employees' => User::all()
        ];
        return view('backend.stock_employee_manage', $data);
    }

    public function view($id)
    {
        $data = [
            'user' => User::where('id', $id)->firstOrFail()
        ];
        return view('backend.stock_employee_view', $data);
    }

    public function create()
    {
        for ($day = 1; $day <= 31; $day++) {
            $data['days'][$day] = $day;
        }

        $data['months'][1] = 'มกราคม';
        $data['months'][2] = 'กุมภาพันธ์';
        $data['months'][3] = 'มีนาคม';
        $data['months'][4] = 'เมษายน';
        $data['months'][5] = 'พฤษภาคม';
        $data['months'][6] = 'มิถุนายน';
        $data['months'][7] = 'กรกฎาคม';
        $data['months'][8] = 'สิงหาคม';
        $data['months'][9] = 'กันยายน';
        $data['months'][10] = 'ตุลาคม';
        $data['months'][11] = 'พฤศจิกายน';
        $data['months'][12] = 'ธันวาคม';

        $year = date('Y');
        $elyear = date('Y') - 100;
        for ($year; $year >= $elyear; $year--) {
            $data['years'][$year] = $year;
        }
        return view('backend.stock_employee_create', $data);
    }

    public function store(EmployeeRequest $request)
    {
        if ($request->input('password') != $request->input('repassword')) {
            return back()->withErrors('รหัสผ่านไม่ตรงกันกรุณากรอกใหม่อีกครั้ง');
        } else {
            if (!User::where('username', $request->input('username'))->count() > 0) {
                $employee = new Profile();
                $employee->fullname = $request->input('fullname');
                $employee->idcard = $request->input('idcard');
                $employee->birthdate = $request->input('year') . '-' . $request->input('month') . '-' . $request->input('day');
                $employee->phone = $request->input('phone');
                $employee->address = $request->input('address');
                if ($employee->save()) {
                    $login = new  User();
                    $login->profile_id = $employee->id;
                    $login->username = $request->input('username');
                    $login->password = bcrypt($request->input('password'));
                    $login->type = $request->input('type');
                    $login->status = 1;
                    if ($login->save()) {
                        return redirect('stock/employee')->with('success', 'เพิ่มข้อมูลพนักงานเรียบร้อย');
                    } else {
                        User::findOrFail($employee->id)->delete();
                        return back()->withErrors('เพิ่มข้อมูลส่วนข้อมูลเข้าสู้ระบบผิดพลาด');
                    }
                } else {
                    return back()->withErrors('เพิ่มข้อมูลส่วนข้อมูลเข้าสู้ระบบผิดพลาด');
                }
            } else {
                return back()->withErrors('ชื่อผู้ใช้ที่จะเพิ่ม ซ้ำ!');
            }
        }
    }

    public function edit($id)
    {
        for ($day = 1; $day <= 31; $day++) {
            $dataBirthDate['days'][$day] = $day;
        }

        $dataBirthDate['months'][1] = 'มกราคม';
        $dataBirthDate['months'][2] = 'กุมภาพันธ์';
        $dataBirthDate['months'][3] = 'มีนาคม';
        $dataBirthDate['months'][4] = 'เมษายน';
        $dataBirthDate['months'][5] = 'พฤษภาคม';
        $dataBirthDate['months'][6] = 'มิถุนายน';
        $dataBirthDate['months'][7] = 'กรกฎาคม';
        $dataBirthDate['months'][8] = 'สิงหาคม';
        $dataBirthDate['months'][9] = 'กันยายน';
        $dataBirthDate['months'][10] = 'ตุลาคม';
        $dataBirthDate['months'][11] = 'พฤศจิกายน';
        $dataBirthDate['months'][12] = 'ธันวาคม';

        $year = date('Y');
        $elyear = date('Y') - 100;
        for ($year; $year >= $elyear; $year--) {
            $dataBirthDate['years'][$year] = $year;
        }

        $data = [
            'employee' => User::where('id', $id)->firstOrFail()
        ];
        return view('backend.stock_employee_edit', $data, $dataBirthDate);
    }

    public function update(EmployeeUpdateForAdminRequest $request, $id = null)
    {
        $login = User::findOrFail($id);
        if (!$request->input('password') == null) {
            if ($request->input('password') != $request->input('repassword')) {
                return back()->withErrors('รหัสผ่านไม่ตรงกันกรุณากรอกใหม่อีกครั้ง');
            } else {
                $login->password = bcrypt($request->input('password'));
            }
        }
        $login->type = $request->input('type');
        $login->status = $request->input('status');
        if ($login->save()) {
            $employee = Profile::findOrFail($login->profile_id);
            $employee->fullname = $request->input('fullname');
            $employee->idcard = $request->input('idcard');
            $employee->birthdate = $request->input('year') . '-' . $request->input('month') . '-' . $request->input('day');
            $employee->phone = $request->input('phone');
            $employee->address = $request->input('address');
            if ($employee->save()) {
                return redirect('stock/employee')->with('success', 'เปลี่ยนแปลงข้อมูลพนักงานเรียบร้อย');
            } else {
                return back()->withErrors('เปลี่ยนแปลงข้อมูลเข้าสู่ระบบผิดพลาด');
            }
        } else {
            return back()->withErrors('เปลี่ยนแปลงข้อมูลเข้าสู่ระบบผิดพลาด');
        }
    }

    public function destroy($id)
    {
        $login = User::findOrFail($id);
        $employee = Profile::findOrFail($login->profile_id);
        if ($employee->delete()) {
            if ($login->delete()) {
                return redirect('stock/employee')->with('success', 'ลบข้อมูลพนักงานเรียบร้อย');
            } else {
                return back()->withErrors('ลบข้อมูลพนักงานผิดพลาด');
            }
        } else {
            return back()->withErrors('ลบข้อมูลส่วนเข้าสู่ระบบผิดพลาด');
        }
    }

    //employee
    public function employeeView($id)
    {
        $data = [
            'user' => User::where('id', $id)->firstOrFail()
        ];
        return view('backend.stock_employee_employeeView', $data);
    }

    public function changePasswordView($id)
    {
        $data = [
            'employee' => User::where('id', $id)->firstOrFail()
        ];
        return view('backend.stock_employee_changePasswordView', $data);
    }

    public function changePassword(EmployeeChangePasswordRequest $request, $id = null)
    {
        $login = User::findOrFail($id);
        if (!Hash::check($request->input('password'), $login->password)) {
            return back()->withErrors('รหัสผ่านเดิมไม่ถูกต้อง');
        } else {
            if ($request->input('newPassword') != $request->input('reNewPassword')) {
                return back()->withErrors('รหัสผ่านใหม่ไม่ตรงกัน');
            } else {
                $login->password = bcrypt($request->input('newPassword'));
                if ($login->save()) {
                    return back()->with('success', 'เปลี่ยนแปลงรหัสผ่านเรียบร้อย');
                } else {
                    return back()->withErrors('เปลี่ยนแปลงรหัสผ่านผิดพลาด');
                }
            }
        }
    }

    public function employeeEdit($id)
    {
        for ($day = 1; $day <= 31; $day++) {
            $dataBirthDate['days'][$day] = $day;
        }

        $dataBirthDate['months'][1] = 'มกราคม';
        $dataBirthDate['months'][2] = 'กุมภาพันธ์';
        $dataBirthDate['months'][3] = 'มีนาคม';
        $dataBirthDate['months'][4] = 'เมษายน';
        $dataBirthDate['months'][5] = 'พฤษภาคม';
        $dataBirthDate['months'][6] = 'มิถุนายน';
        $dataBirthDate['months'][7] = 'กรกฎาคม';
        $dataBirthDate['months'][8] = 'สิงหาคม';
        $dataBirthDate['months'][9] = 'กันยายน';
        $dataBirthDate['months'][10] = 'ตุลาคม';
        $dataBirthDate['months'][11] = 'พฤศจิกายน';
        $dataBirthDate['months'][12] = 'ธันวาคม';

        $year = date('Y');
        $elyear = date('Y') - 100;
        for ($year; $year >= $elyear; $year--) {
            $dataBirthDate['years'][$year] = $year;
        }

        $data = [
            'employee' => User::where('id', $id)->firstOrFail()
        ];
        return view('backend.stock_employee_employeeEdit', $data, $dataBirthDate);
    }

    public function employeeUpdate(EmployeeUpdateRequest $request, $id = null)
    {
        $login = User::findOrFail($id);
        $employee = Profile::findOrFail($login->profile_id);
        $employee->fullname = $request->input('fullname');
        $employee->idcard = $request->input('idcard');
        $employee->birthdate = $request->input('year') . '-' . $request->input('month') . '-' . $request->input('day');
        $employee->phone = $request->input('phone');
        $employee->address = $request->input('address');
        if ($employee->save()) {
            return back()->with('success', 'เปลี่ยนแปลงข้อมูลพนักงานเรียบร้อย');
        } else {
            return back()->withErrors('เปลี่ยนแปลงข้อมูลเข้าสู่ระบบผิดพลาด');
        }
    }

}
