<?php

namespace App\Http\Controllers;


use App\Category;
use App\Http\Requests\ProductPickUpRequest;
use App\Http\Requests\ProductRequest;
use App\Http\Requests\ProductUpdateRequest;
use App\Location;
use App\Product;
use App\Stock;
use App\StockLog;
use App\Supplier;
use App\Unit;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ProductController extends Controller
{
    public function index()
    {
        $data = [
            'products' => Product::all()
        ];
        return view('backend.stock_product_manage', $data);
    }

    public function create()
    {
        if (Category::count() > 0 and Location::count() > 0 and Supplier::where('status', 0)->count() > 0) {
            if (Product::count() > 0) {
                $barcode = str_pad(Product::orderBy('id', 'desc')->limit(1)->first()->barcode + 1, 6, '0', STR_PAD_LEFT);
            } else {
                $barcode = '000001';
            }
            $data = [
                'categories' => Category::pluck('name', 'id'),
                'locations' => Location::pluck('name', 'id'),
                'suppliers' => Supplier::where('status', 0)->pluck('name', 'id'),
                'barcode' => $barcode
            ];
            return view('backend.stock_product_create', $data);
        } else {
            echo 'หมวดหมู่ ผู้ผลิต หรือสถานที่เก็บยังไม่มีข้อมูล ไม่สามารถเพิ่มสินค้าได้';
        }
    }

    public function store(ProductRequest $request)
    {
        $unit = new Unit();
        $unit->supplier_id = $request->input('supplier_id');
        $unit->name = $request->input('unit_name');
        $unit->amount = $request->input('unit_amount');
        $unit->perpiece = $request->input('unit_perpiece');
        $unit->price = $request->input('unit_price');
        $unit->status = 0;
        if ($unit->save()) {
            $product = new Product();
            $product->category_id = $request->input('category_id');
            $product->name = $request->input('name');
            if (Product::count() > 0) {
                $barcode = str_pad(Product::orderBy('id', 'desc')->limit(1)->first()->barcode + 1, 6, '0', STR_PAD_LEFT);
            } else {
                $barcode = '000001';
            }
            $product->barcode = $barcode;
            $product->amount = 0;
            $product->costprice = $request->input('unit_price') / $request->input('unit_perpiece');
            $product->price = $request->input('price');
            if ($product->save()) {
                $stock = new Stock();
                if (Stock::count() > 0) {
                    $code = str_pad(Stock::orderBy('id', 'desc')->limit(1)->first()->code + 1, 6, '0', STR_PAD_LEFT);
                } else {
                    $code = '000001';
                }
                $stock->code = $code;
                $stock->product_id = $product->id;
                $stock->unit_id = $unit->id;
                $stock->location_id = $request->input('location_id');
                $stock->amount = $request->input('unit_amount') * $request->input('unit_perpiece');
                $stock->status = 0;
                if ($stock->save()) {
                    $stockLog = new StockLog();
                    $stockLog->product_name = $product->name;
                    $stockLog->product_barcode = $product->barcode;
                    $stockLog->location = $stock->location->name;
                    $stockLog->amount = $request->input('unit_amount') * $request->input('unit_perpiece');
                    $stockLog->fullname = Auth::user()->profile->fullname;
                    $stockLog->type = 0;
                    $stockLog->save();
                    return redirect('stock/product')->with('success', 'เพิ่มข้อมูลสินค้าเรียบร้อย');
                } else {
                    Unit::findOrFail($unit->id)->delete();
                    Product::findOfFail($product->id)->delete();
                    return back()->withErrors('เพิ่มข้อมูลส่วนข้อมูลสินค้าหรือส่วยสต๊อกผิดพลาด');
                }
            } else {
                Unit::findOrFail($unit->id)->delete();
                return back()->withErrors('เพิ่มข้อมูลส่วนข้อมูลสินค้าผิดพลาด');
            }
        } else {
            return back()->withErrors('เพิ่มข้อมูลสินค้าผิดพลาด');
        }
    }

    public function edit($id)
    {
        if (Category::count() > 0) {
            $data = [
                'stock' => Stock::where('id', $id)->firstOrFail(),
                'categories' => Category::pluck('name', 'id'),
            ];
            return view('backend.stock_product_edit', $data);
        } else {
            echo 'หมวดหมู่ยังไม่มีข้อมูล ไม่สามารถเพิ่มสินค้าได้';
        }
    }

    public function update(ProductUpdateRequest $request, $id = null)
    {
        $product = Product::findOrFail($id);
        $product->category_id = $request->input('category_id');
        $product->name = $request->input('name');
        $product->price = $request->input('price');
        if ($product->save()) {
            return redirect('stock/product')->with('success', 'เปลี่ยนแปลงข้อมูลสินค้าเรียบร้อย');
        } else {
            return back()->withErrors('เปลี่ยนแปลงข้อมูลสินค้าผิดพลาด');
        }
    }

    public function destroy($id)
    {
        $product = Product::findOrFail($id);
        $stocks = Stock::where('product_id', $product->id)->get();
        foreach ($stocks as $stock) {
            Unit::findOrFail($stock->unit_id)->delete();
            $stock->delete();
        }
        if ($product->delete()) {
            return redirect('stock/product')->with('success', 'ลบข้อมูลสินค้าและหน่วยนับเรียบร้อย');
        } else {
            return back()->withErrors('ลบข้อมูลส่วนสินค้าผิดพลาด');
        }
    }

    public function productPickUpView($id)
    {
        $data = [
            'product' => Product::findOrFail($id),
            'stocks' => Stock::where('product_id', $id)->where('amount', '>', 0)->get()
        ];
        return view('backend.stock_product_pickUpView', $data);
    }

    public function productPickUp(ProductPickUpRequest $request, $id = null)
    {
        if ($request->input('pickUp') > Stock::where('product_id', $id)->sum('amount')) {
            return back()->withErrors('จำนวนเบิกเกินจำนวน');
        } else {
            $pickUp = $request->input('pickUp');
            $stocks = Stock::where('product_id', $id)->where('amount', '>', 0)->orderBy('created_at')->get();
            foreach ($stocks as $item) {
                if ($pickUp > 0) {
                    if ($pickUp > $item->amount) {
                        $pickUp = $pickUp - $item->amount;
                        $item->amount = 0;
                        $item->status = 1;
                        $item->save();
                        $unit = Unit::find($item->unit_id);
                        $unit->status = 1;
                        $unit->save();
                    } else {
                        $item->amount = $item->amount - $pickUp;
                        $item->status = 1;
                        $item->save();
                        $stockLog = new StockLog();
                        $stockLog->product_name = $item->product->name;
                        $stockLog->product_barcode = $item->product->barcode;
                        $stockLog->location = $item->location->name;
                        $stockLog->amount = $pickUp;
                        $stockLog->fullname = Auth::user()->profile->fullname;
                        $stockLog->type = 1;
                        $stockLog->save();
                        $pickUp = 0;
                        $unit = Unit::find($item->unit_id);
                        $unit->status = 1;
                        $unit->save();
                    }
                }
            }
        }
        $product = Product::findOrFail($id);
        $product->amount = $product->amount + $request->input('pickUp');
        if ($product->save()) {
            return redirect('stock/product')->with('success', 'เบิกสินค้าเรียบร้อย');
        } else {
            return back()->withErrors('เบิกสินค้าผิดพลาด');
        }
    }

    public function addView($id)
    {
        $data = [
            'product' => Product::findOrFail($id),
            'locations' => Location::pluck('name', 'id'),
            'suppliers' => Supplier::where('status', 0)->pluck('name', 'id'),
        ];
        return view('backend.stock_product_addView', $data);
    }

    public function addStore(Request $request, $id)
    {
        $this->validate($request, [
            'unit_perpiece' => 'required|numeric',
            'unit_name' => 'required',
            'unit_amount' => 'required|numeric',
            'unit_price' => 'required|numeric'
        ],[
            'unit_name.required' => 'ช่องกรอกชื่อหน่วยนับจำเป็นต้องมีข้อมูล',
            'unit_amount.required' => 'ข้อมูลจำนวนต่อหน่วยจำเป็นต้นมีข้อมูล',
            'unit_amount.numeric' => 'ควรมีข้อมูลจำนวนต่อหน่วยเป็นตัวเลข',
            'unit_perpiece.required' => 'ข้อมูลหน่วยต่อชิ้นจำเป็นต้นมีข้อมูล',
            'unit_perpiece.numeric' => 'ควรมีข้อมูลหน่วยต่อชิ้นเป็นตัวเลข',
            'unit_price.required' => 'ข้อมูลราคาต่อหน่วยจำเป็นต้นมีข้อมูล',
            'unit_price.numeric' => 'ควรมีข้อมูลราคาต่อหน่วยเป็นตัวเลข'
        ]);
        $product = Product::findOrFail($id);
        $unit = new Unit();
        $unit->supplier_id = $request->input('supplier_id');
        $unit->name = $request->input('unit_name');
        $unit->amount = $request->input('unit_amount');
        $unit->perpiece = $request->input('unit_perpiece');
        $unit->price = $request->input('unit_price');
        $unit->status = 0;
        if ($unit->save()) {
            $stock = new Stock();
            if (Stock::count() > 0) {
                $code = str_pad(Stock::orderBy('id', 'desc')->limit(1)->first()->code + 1, 6, '0', STR_PAD_LEFT);
            } else {
                $code = '000001';
            }
            $stock->code = $code;
            $stock->product_id = $product->id;
            $stock->unit_id = $unit->id;
            $stock->location_id = $request->input('location_id');
            $stock->amount = $request->input('unit_amount') * $request->input('unit_perpiece');
            $stock->status = 0;
            if ($stock->save()) {

                $all_per_unit = 0;
                $all_price_unit = 0;
                foreach (Stock::where('product_id', $product->id)->get() as $item) {
                    $all_per_unit += $item->unit->perpiece;
                    $all_price_unit += $item->unit->price;
                }

                $product->costprice = $all_price_unit / $all_per_unit;
                $product->save();

                $stockLog = new StockLog();
                $stockLog->product_name = $product->name;
                $stockLog->product_barcode = $product->barcode;
                $stockLog->location = $stock->location->name;
                $stockLog->amount = $request->input('unit_amount') * $request->input('unit_perpiece');
                $stockLog->fullname = Auth::user()->profile->fullname;
                $stockLog->type = 0;
                $stockLog->save();
                return redirect('stock/product')->with('success', 'เพิ่มสินค้าในสต๊อกเรียบร้อย');
            } else {
                Unit::findOrFail($unit->id)->delete();
                return back()->withErrors('เพิ่มสินค้าในสต๊อกเรียบร้อยผิดพลาด');
            }
        } else {
            return back()->withErrors('เพิ่มสินค้าในสต๊อกเรียบร้อย');
        }
    }
}
