<?php
/**
 * Created by PhpStorm.
 * User: sataw
 * Date: 9/3/2560
 * Time: 20:15
 */

namespace App\Http\Controllers;

use App\Cart;
use App\Http\Requests\AddCartRequest;
use App\Http\Requests\SaleSummaryRequest;
use App\Product;
use App\Sale;
use App\SaleDetail;
use App\Stock;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Auth;

class WelcomeController extends Controller
{
    public function index()
    {
        if (!Session::has('cart')) {
            return view('frontend.home', ['products' => null]);
        }
        $oldCart = Session::get('cart');
        $cart = new Cart($oldCart);
        return view('frontend.home', ['products' => $cart->items, 'totalPrice' => $cart->totalPrice]);
    }

    public function addCart(AddCartRequest $request)
    {
        $barcode = $request->input('barcode');
        $amount = $request->input('amount');
        $pointer = strpos($barcode, '*');
        if ($pointer) {
            $qty = substr($barcode, 0, $pointer);
            $product_barcode = substr($barcode, $pointer + 1);
        } else {
            $qty = $amount;
            $product_barcode = $barcode;
        }
        $product = Product::where('barcode', $product_barcode)->first();
        if ($product->count() > 0) {
            $oldCart = Session::has('cart') ? Session::get('cart') : null;
            $cart = new Cart($oldCart);
            if ($cart->add($product, $product->id, $qty)) {
                $request->session()->put('cart', $cart);
                return response()->json(['type' => 'success', 'cart' => $cart]);
            } else {
                return response()->json(['type' => 'error', 'content' => 'จำนวนสินค้ามีไม่เพียงพอ']);
            }
        } else {
            return response()->json(['type' => 'error', 'content' => 'ไม่พบสินค้า']);
        }
    }

    public function saleSummary(SaleSummaryRequest $request)
    {
        if (Session::has('cart')) {
            if ($request->input('cash') < Session::get('cart')->totalPrice) {
                return back()->withErrors('เงินที่รับไม่ถูกต้อง');
            } else {
                $sale = new Sale();
                $sale->user_id = Auth::user()->id;
                if (Sale::count() > 0) {
                    $sale_code = str_pad(Sale::orderBy('id', 'desc')->limit(1)->first()->sale_code + 1, 6, '0', STR_PAD_LEFT);
                } else {
                    $sale_code = '000001';
                }
                $sale->sale_code = $sale_code;
                $sale->user_fullname = Auth::user()->profile->fullname;
                $sale->cash = $request->input('cash');
                $sale->change = $request->input('cash') - Session::get('cart')->totalPrice;
                $sale->price_total = Session::get('cart')->totalPrice;
                $sale->status = 1;
                if ($sale->save()) {
                    foreach (Session::get('cart')->items as $item) {
                        $saleDetail = new SaleDetail();
                        $saleDetail->sale_id = $sale->id;
                        $saleDetail->product_id = $item['item']['id'];
                        $saleDetail->product_barcode = $item['item']['barcode'];
                        $saleDetail->product_name = $item['item']['name'];
                        $saleDetail->amount = $item['qty'];
                        $saleDetail->price = $item['price'];
                        $saleDetail->save();

                        $product = Product::findOrFail($item['item']['id']);
                        $product->amount = $product->amount - $item['qty'];
                        $product->save();
                    }
                    Session::forget('cart');
                    echo "<script>window.open('" . url('salePrint/' . $sale->id) . "', '_blank')</script>";
                    echo "<script>window.location='" . url('/') . "';</script>";
                } else {
                    Sale::findOrFail($sale->id)->delete();
                    return back()->withErrors('ทำการขายล้มเหลว');
                }
            }
        }
    }

    public function productCheck($barcode)
    {
        if ($barcode == null) {
            return 'กรุณากรอกรหัสสินค้าด้วย';
        } elseif (Product::where('barcode', $barcode)->get()->count() > 0) {
            $product = Product::where('barcode', $barcode)->firstOrFail();
            $data = [
                'stocks' => Stock::where('product_id', $product->id)->get(),
                'product' => $product
            ];
            return view('frontend.productCheck_view', $data);
        } else {
            return 'ไม่พบข้อมูลสินค้า';
        }
    }

    public function destroyCart()
    {
        Session::forget('cart');
        if (!Session::has('cart')) {
            return response()->json(['type' => 'success', 'title' => 'สำเร็จ', 'content' => 'ล้างตะกร้าเรียบร้อย']);
        } else {
            return response()->json(['type' => 'error', 'title' => 'ล้มเหลว', 'content' => 'การล้างตะกร้าผิดพลาด']);
        }
    }

    public function salePrint($id)
    {
        $sale = Sale::findOrFail($id);
        $saleDetail = SaleDetail::where('sale_id', $sale->id)->get();
        $data = [
            'sale' => $sale,
            'saleDetails' => $saleDetail
        ];
        return view('frontend.salePrint_view', $data);
    }

    public function removeProductCart($id)
    {
        $oldCart = Session::has('cart') ? Session::get('cart') : null;
        $cart = new Cart($oldCart);
        if ($cart->remove($id)) {
            Session::put('cart', $cart);
            return response()->json(['type' => 'success', 'cart' => $cart, 'id' => $id]);
        }
    }

    public function changeDown($id)
    {
        $product = Product::find($id);
        if ($product->count() > 0) {
            $oldCart = Session::has('cart') ? Session::get('cart') : null;
            $cart = new Cart($oldCart);
            if ($cart->add($product, $id, -1)) {
                Session::put('cart', $cart);
                return response()->json(['type' => 'success', 'cart' => $cart]);
            } else {
                return response()->json(['type' => 'error', 'content' => 'จำนวนสินค้ามีไม่เพียงพอ หรือจำนวนสินค้าน้อยกว่ากำหนด']);
            }
        } else {
            return response()->json(['type' => 'error', 'content' => 'ไม่พบสินค้า']);
        }
    }

    public function changeUp($id)
    {
        $product = Product::find($id);
        if ($product->count() > 0) {
            $oldCart = Session::has('cart') ? Session::get('cart') : null;
            $cart = new Cart($oldCart);
            if ($cart->add($product, $id, 1)) {
                Session::put('cart', $cart);
                return response()->json(['type' => 'success', 'cart' => $cart]);
            } else {
                return response()->json(['type' => 'error', 'content' => 'จำนวนสินค้ามีไม่เพียงพอ']);
            }
        } else {
            return response()->json(['type' => 'error', 'content' => 'ไม่พบสินค้า']);
        }
    }
}
