<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Auth::routes();

Route::group(['middleware' => ['auth', 'employee']], function () {
    Route::get('/', 'WelcomeController@index');
    Route::get('productCheck/{barcode}', 'WelcomeController@productCheck');
    Route::post('addCart', 'WelcomeController@addCart');
    Route::post('saleSummary', 'WelcomeController@saleSummary');
    Route::get('salePrint/{id}', 'WelcomeController@salePrint');
    Route::get('destroyCart', 'WelcomeController@destroyCart');
    Route::get('removeProductCart/{id}', 'WelcomeController@removeProductCart');
    Route::get('changeDown/{id}', 'WelcomeController@changeDown');
    Route::get('changeUp/{id}', 'WelcomeController@changeUp');

    Route::group(['prefix' => 'stock'], function () {
        Route::get('/', 'StockController@index');

        Route::get('sale', 'SaleController@index');
        Route::get('sale/saleLogs', 'SaleController@saleLogs');
        Route::get('sale/detailView/{id}', 'SaleController@saleDetailView');
        Route::get('sale/cancelSale/{id}', 'SaleController@cancelSale');

        Route::get('product', 'ProductController@index');
        Route::get('product/create', 'ProductController@create');
        Route::post('product/store', 'ProductController@store');
        Route::get('product/edit/{id}', 'ProductController@edit');
        Route::post('product/update/{id}', 'ProductController@update');
        Route::get('product/pickUpView/{id}', 'ProductController@productPickUpView');
        Route::post('product/pickUp/{id}', 'ProductController@productPickUp');
        Route::get('product/addView/{id}', 'ProductController@addView');
        Route::post('product/addStore/{id}', 'ProductController@addStore');


        Route::get('category', 'CategoryController@index');
        Route::get('category/create', 'CategoryController@create');
        Route::post('category/store', 'CategoryController@store');
        Route::get('category/edit/{id}', 'CategoryController@edit');
        Route::post('category/update/{id}', 'CategoryController@update');

        Route::get('location', 'LocationController@index');
        Route::get('location/create', 'LocationController@create');
        Route::post('location/store', 'LocationController@store');
        Route::get('location/edit/{id}', 'LocationController@edit');
        Route::post('location/update/{id}', 'LocationController@update');

        Route::get('supplier', 'SupplierController@index');
        Route::get('supplier/create', 'SupplierController@create');
        Route::post('supplier/store', 'SupplierController@store');
        Route::get('supplier/edit/{id}', 'SupplierController@edit');
        Route::post('supplier/update/{id}', 'SupplierController@update');

        Route::get('unit', 'UnitController@index');
        Route::get('unit/edit/{id}', 'UnitController@edit');
        Route::post('unit/update/{id}', 'UnitController@update');

        //employee
        Route::get('employee/employeeView/{id}', 'EmployeeController@employeeView');
        Route::get('employee/changePasswordView/{id}', 'EmployeeController@changePasswordView');
        Route::post('employee/changePassword/{id}', 'EmployeeController@changePassword');
        Route::get('employee/employeeEdit/{id}', 'EmployeeController@employeeEdit');
        Route::post('employee/employeeUpdate/{id}', 'EmployeeController@employeeUpdate');

        Route::group(['middleware' => 'secret'], function () {
            Route::get('logs', 'StockController@stockLog');

            Route::get('account/days', 'AccountController@accountDays');
            Route::get('account/months', 'AccountController@accountMonths');
            Route::get('account/years', 'AccountController@accountYears');

            Route::get('employee', 'EmployeeController@index');
            Route::get('employee/view/{id}', 'EmployeeController@view');
            Route::get('employee/create', 'EmployeeController@create');
            Route::post('employee/store', 'EmployeeController@store');
            Route::get('employee/edit/{id}', 'EmployeeController@edit');
            Route::post('employee/update/{id}', 'EmployeeController@update');
            Route::get('employee/destroy/{id}', 'EmployeeController@destroy');

            Route::get('product/destroy/{id}', 'ProductController@destroy');

            Route::get('category/destroy/{id}', 'CategoryController@destroy');

            Route::get('location/destroy/{id}', 'LocationController@destroy');

            Route::get('supplier/destroy/{id}', 'SupplierController@destroy');

        });
    });
});
